#
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.
"""Exceptions used by Docker provider."""
from __future__ import annotations

from airflow.exceptions import AirflowException, AirflowSkipException


class DockerContainerFailedException(AirflowException):
    """
    Raised when a Docker container returns an error.

    :param logs: The log output of the failed Docker container
    """

    def __init__(self, message: str | None = None, logs: list[str | bytes] | None = None) -> None:
        super().__init__(message)
        self.logs = logs


class DockerContainerFailedSkipException(AirflowSkipException):
    """
    Raised when a Docker container returns an error and task should be skipped.

    :param logs: The log output of the failed Docker container
    """

    def __init__(self, message: str | None = None, logs: list[str | bytes] | None = None) -> None:
        super().__init__(message)
        self.logs = logs
